Struct amazon_sp_shipping::models::service_rate::ServiceRate
source · [−]pub struct ServiceRate {
pub total_charge: Box<Currency>,
pub billable_weight: Box<Weight>,
pub service_type: ServiceType,
pub promise: Box<ShippingPromiseSet>,
}Expand description
ServiceRate : The specific rate for a shipping service, or null if no service available.
Fields
total_charge: Box<Currency>billable_weight: Box<Weight>service_type: ServiceTypepromise: Box<ShippingPromiseSet>Implementations
sourceimpl ServiceRate
impl ServiceRate
sourcepub fn new(
total_charge: Currency,
billable_weight: Weight,
service_type: ServiceType,
promise: ShippingPromiseSet
) -> ServiceRate
pub fn new(
total_charge: Currency,
billable_weight: Weight,
service_type: ServiceType,
promise: ShippingPromiseSet
) -> ServiceRate
The specific rate for a shipping service, or null if no service available.